@@ -1,14 +1,11 @@
-import pandas as pd
 import numpy as np
 import pdpipe as pdp
 import mplfinance as mpf
-from datetime import datetime, timedelta
 from pdpipe import PdPipelineStage
 
 from pdsando.ta.datafeeds.polygon import Polygon
 from pdsando.ta.pipeline.indicators import SuperTrend, DonchianRibbon, EMA, RollingMax, RateOfChange, HL2, AverageDirectionalIndex, BuySell
-from pdsando.ta.pipeline.filters import RemoveNonMarketHours
-from pdsando.ta.pipeline.transforms import Shift, ResetIndex, ThirtyToSixty, ColKeep, IntradayGroups
+from pdsando.ta.pipeline.transforms import ResetIndex, IntradayGroups
 
 class Strategy(PdPipelineStage):
   
@@ -59,7 +56,7 @@ class Strategy(PdPipelineStage):
 
 class Blender(Strategy):
   
-  def __init__(self, tgt_col, close='Close', high='High', ts='Timestamp', supertrend_multiplier=1.5, donchian_period=21, donchian_thresh=-7, trail_frac=0.01, sell_eod=False, debug=False, **kwargs):
+  def __init__(self, tgt_col, close='Close', high='High', supertrend_multiplier=1.5, donchian_period=21, donchian_thresh=-7, trail_frac=0.01, sell_eod=False, debug=False, **kwargs):
     self._tgt_col = tgt_col
     self._supertrend_multiplier = supertrend_multiplier
     self._donchian_period = donchian_period
@@ -67,7 +64,6 @@ class Blender(Strategy):
     self._debug = debug
     self._close = close
     self._high = high
-    self._ts = ts
     super().__init__(tgt_col=tgt_col, close=close, high=high, trail_frac=trail_frac, sell_eod=sell_eod, **kwargs)
   
   def _preprocess(self, df):
@@ -90,7 +86,7 @@ class Blender(Strategy):
     agg = pipeline.apply(agg_raw)
     
     # Join dataframes and filter down to possible setups
-    j = primary.join(agg.set_index(self._ts), on=self._ts, rsuffix='_agg', how='left')
+    j = primary.join(agg, rsuffix='_agg', how='left')
     
     j[self._tgt_col] = 0
     
@@ -106,4 +102,4 @@ class Blender(Strategy):
       self._tgt_col
     ] = 1
     
-    return df.join(j.set_index(self._ts)[[self._tgt_col]], on=self._ts, how='left').fillna(method='ffill')
\ No newline at end of file
+    return df.join(j, how='left').fillna(method='ffill')
\ No newline at end of file
