@@ -1,11 +1,5 @@
-import pytz
-from pytz import timezone
 import pandas as pd
-import numpy as np
-from datetime import datetime, timedelta
 from pdpipe import PdPipelineStage
-from pdsando.ta.pipeline.filters import RemoveNonMarketHours
-import mplfinance as mpf
 
 class Transform(PdPipelineStage):
   
@@ -43,11 +37,12 @@ class Shift(Transform):
 
 class ToDateTime(Transform):
   
-  def __init__(self, tgt_col, src_col, unit='ms', to_tz='utc', **kwargs):
+  def __init__(self, tgt_col, src_col, unit='ms', to_tz='utc', strip_tz=True, **kwargs):
     self._tgt_col = tgt_col
     self._src_col = src_col
     self._unit = unit
     self._to_tz = to_tz
+    self._strip_tz = strip_tz
     super().__init__()
   
   def _transform(self, df, verbose):
@@ -61,6 +56,9 @@ class ToDateTime(Transform):
     if self._to_tz != 'utc':
       ret_df[self._tgt_col] = ret_df[self._tgt_col].dt.tz_convert(self._to_tz)
     
+    if self._strip_tz:
+      ret_df[self._tgt_col] = pd.DatetimeIndex(ret_df[self._tgt_col]).tz_localize(None)
+    
     return ret_df
 
 class ResetIndex(Transform):
@@ -113,9 +111,8 @@ class MaxVal(Transform):
 
 class FillMissingTimeFrames(Transform):
   
-  def __init__(self, delta, timestamp='Timestamp', from_time='9:30', to_time='16:00', **kwargs):
+  def __init__(self, delta, from_time='9:30', to_time='16:00', **kwargs):
     self._delta = delta
-    self._timestamp = timestamp
     self._from_time = from_time
     self._to_time = to_time
     super().__init__()
@@ -149,57 +146,11 @@ class FillMissingTimeFrames(Transform):
       end_minute = int(self._to_time.split(':')[1])
     )
     
-    j = dt_ref.join(df.set_index(df[self._timestamp].dt.hour*60 + df[self._timestamp].dt.minute), how='left').sort_values(by=self._timestamp).reset_index(drop=True)
+    j = dt_ref.join(df.set_index(df.index.hour*60 + df.index.minute), how='left')
     j.fillna(method='ffill')
     
     return j[list(df.columns)]
 
-# TODO PERFORMANCE OPTIMIZATIONS
-class ThirtyToSixty(Transform):
-  
-  def __init__(self, open='Open', high='High', low='Low', close='Cloe', volume='Volume', timestamp='Timestamp', prefilter_market_hours=True, **kwargs):
-    self._open = open
-    self._high = high
-    self._low = low
-    self._close = close
-    self._volume = volume
-    self._timestamp = timestamp
-    self._prefilter_market_hours = prefilter_market_hours
-    super().__init__()
-  
-  def _transform(self, df, verbose):
-    ret_df = df.copy()
-    
-    if verbose:
-      print('Reducing 30 minute candles to 60')
-    
-    if self._prefilter_market_hours:
-      ret_df = RemoveNonMarketHours(self._timestamp).apply(ret_df)
-    
-    ret_df['_group'] = ret_df.apply(lambda row: '{} {}:{}'.format(
-      row[self._timestamp].date() if row[self._timestamp].hour != 0 else row[self._timestamp].date()-timedelta(days=1),
-      row[self._timestamp].hour if row[self._timestamp].minute != 0 else (row[self._timestamp] - timedelta(hours=1)).hour,
-      30
-    ), axis=1)
-    
-    cols_to_select = [
-      self._open, self._high,
-      self._low, self._close,
-      self._volume, self._timestamp,
-      '_group'
-    ]
-    
-    ret_df = ret_df[cols_to_select].groupby('_group').agg({
-      self._close: 'last',
-      self._high: 'max',
-      self._low: 'min',
-      self._open: 'first',
-      self._timestamp: 'min',
-      self._volume: 'sum'
-    }).sort_values(by=self._timestamp).reset_index(drop=True)
-    
-    return ret_df
-
 class SetIndex(Transform):
   
   def __init__(self, new_index, **kwargs):
@@ -241,14 +192,13 @@ class Slice(Transform):
 
 class IntradayGroups(Transform):
   
-  def __init__(self, group_size=2, open='Open', high='High', low='Low', close='Close', volume='Volume', timestamp='Timestamp', **kwargs):
+  def __init__(self, group_size=2, open='Open', high='High', low='Low', close='Close', volume='Volume', **kwargs):
     self._group_size = group_size
     self._open = open
     self._high = high
     self._low = low
     self._close = close
     self._volume = volume
-    self._timestamp = timestamp
     super().__init__()
   
   def _transform(self, df, verbose):
@@ -267,35 +217,7 @@ class IntradayGroups(Transform):
       self._open: 'first',
       self._timestamp: 'min',
       self._volume: 'sum'
-    }).sort_values(by=self._timestamp).reset_index(drop=True)
-
-class BuySellOld(Transform):
-  
-  def __init__(self, tgt_col, src_col, short=False, **kwargs):
-    self._tgt_col = tgt_col
-    self._src_col = src_col
-    self._short = short
-    super().__init__()
-  
-  def _transform(self, df, verbose):
-    ret_df = df.copy()
-    
-    if verbose:
-      print('Converting raw signals ({}) to BuySell timeline events ({})"'.format(self._src_col, self._tgt_col))
-    
-    in_pos = False if not self._short else True
-    ret_df[self._tgt_col] = np.nan
-    for i in range(len(ret_df)):
-      if ret_df[self._src_col].iat[i] > 0 and not in_pos:
-        ret_df[self._tgt_col].iat[i] = 1
-        in_pos = True
-      elif ret_df[self._src_col].iat[i] < 0 and in_pos:
-        ret_df[self._tgt_col].iat[i] = -1
-        in_pos = False
-      elif (not self._short and in_pos) or (self._short and not in_pos):
-        ret_df[self._tgt_col].iat[i] = 0
-    
-    return ret_df
+    })
 
 class Invert(Transform):
   
